@@ -73,7 +73,7 @@ def gr(input_file, dr=0.04, grandcanonical=False, ndim=-1, rmax=-1.0, *input_fil
         backend = pp.RadialDistributionFunctionLegacy
     else:
         backend = pp.RadialDistributionFunction
-        
+
     for th in _get_trajectories([input_file] + list(input_files), global_args):
         th._grandcanonical = grandcanonical
         cf = backend(th, dr=dr, rmax=rmax,
@@ -126,7 +126,7 @@ def sk(input_file, nk=20, dk=0.1, kmin=-1.0, kmax=15.0, ksamples=30,
                           field=weight,
                           fluctuations=weight_fluctuations)
             cf.do(update=global_args['update'])
-            
+
 def ik(input_file, trajectory_radius=None, nk=20, dk=0.1, kmin=-1.0,
        kmax=15.0, kgrid=None, ksamples=30, *input_files,
        **global_args):
@@ -161,7 +161,7 @@ def msd(input_file, tmax=-1.0, tmax_fraction=0.75, tsamples=30,
                                   norigins=global_args['norigins'],
                                   sigma=sigma, rmax=rmsd_max, no_offset=no_offset,
                                   fix_cm=fix_cm).do(update=global_args['update'])
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.MeanSquareDisplacement, ids, th, tgrid=t_grid,
                     norigins=global_args['norigins'], sigma=sigma,
                     rmax=rmsd_max, no_offset=no_offset).do(update=global_args['update'])
@@ -180,7 +180,7 @@ def vacf(input_file, tmax=-1.0, tmax_fraction=0.10,
             t_grid = None
         pp.VelocityAutocorrelation(th, t_grid, norigins=global_args['norigins']).do(update=global_args['update'])
         ids = distinct_species(th[0].particle)
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.VelocityAutocorrelation, ids, th,
                     t_grid, norigins=global_args['norigins']).do(update=global_args['update'])
 
@@ -205,9 +205,9 @@ def fkt(input_file, tmax=-1.0, tmax_fraction=0.75,
         ids = distinct_species(th[0].particle)
         if total or len(ids) == 1:
             pp.IntermediateScattering(th, k_grid, t_grid,
-                    norigins=global_args['norigins'],
-                    nk=nk, dk=dk, fix_cm=fix_cm).do(update=global_args['update'])
-        if len(ids) > 1:
+                                      norigins=global_args['norigins'],
+                                      nk=nk, dk=dk, fix_cm=fix_cm).do(update=global_args['update'])
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.IntermediateScattering, ids, th, k_grid, t_grid,
                     norigins=global_args['norigins'],
                     nk=nk, dk=dk, fix_cm=fix_cm).do(update=global_args['update'])
@@ -239,7 +239,7 @@ def fskt(input_file, tmax=-1.0, tmax_fraction=0.75, tsamples=60,
             backend(th, k_grid, t_grid, nk, dk=dk,
                     norigins=global_args['norigins'], fix_cm=fix_cm,
                     lookup_mb=lookup_mb).do(update=global_args['update'])
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(backend, ids, th, k_grid, t_grid, nk, dk=dk,
                     norigins=global_args['norigins'], fix_cm=fix_cm,
                     lookup_mb=lookup_mb).do(update=global_args['update'])
@@ -283,7 +283,7 @@ def alpha2(input_file, tmax=-1.0, tmax_fraction=0.75,
             t_grid = None
         pp.NonGaussianParameter(th, t_grid, norigins=global_args['norigins']).do(update=global_args['update'])
         ids = distinct_species(th[0].particle)
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.NonGaussianParameter, ids, th, t_grid,
                     norigins=global_args['norigins']).do(update=global_args['update'])
 
@@ -301,7 +301,7 @@ def qst(input_file, tmax=-1.0, tmax_fraction=0.75,
             t_grid = None
         pp.SelfOverlap(th, t_grid, norigins=global_args['norigins']).do(update=global_args['update'])
         ids = distinct_species(th[0].particle)
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.SelfOverlap, ids, th, t_grid,
                     norigins=global_args['norigins']).do(update=global_args['update'])
 
@@ -319,7 +319,7 @@ def qt(input_file, tmax=-1.0, tmax_fraction=0.75,
             t_grid = None
         pp.CollectiveOverlap(th, t_grid, norigins=global_args['norigins']).do(update=global_args['update'])
         ids = distinct_species(th[0].particle)
-        if len(ids) > 1:
+        if len(ids) > 1 and not global_args['no_partial']:
             Partial(pp.CollectiveOverlap, ids, th, t_grid,
                     norigins=global_args['norigins']).do(update=global_args['update'])
 
